@@ -11,7 +11,7 @@ class BlockchainProtocol(Enum):
         return self is other or str(self) == str(other)
 
     def __str__(self) -> str:
-        return self.value
+        return str(self.value)
 
     def __hash__(self) -> int:
         return id(self)
