@@ -1,4 +1,4 @@
-from typing import Union, List
+from typing import Union, List, Optional
 
 from bxcommon.messages.abstract_message import AbstractMessage
 from bxcommon.utils import convert
@@ -7,9 +7,15 @@ from bxcommon.messages.abstract_block_message import AbstractBlockMessage
 
 from bxgateway.connections.eth.eth_base_connection_protocol import EthBaseConnectionProtocol
 from bxgateway.messages.eth.protocol.block_bodies_eth_protocol_message import BlockBodiesEthProtocolMessage
+from bxgateway.messages.eth.protocol.block_bodies_v66_eth_protocol_message import \
+    BlockBodiesV66EthProtocolMessage
 from bxgateway.messages.eth.protocol.eth_protocol_message_type import EthProtocolMessageType
 from bxgateway.messages.eth.protocol.get_block_bodies_eth_protocol_message import GetBlockBodiesEthProtocolMessage
+from bxgateway.messages.eth.protocol.get_block_bodies_v66_eth_protocol_message import \
+    GetBlockBodiesV66EthProtocolMessage
 from bxgateway.messages.eth.protocol.receipts_eth_protocol_message import ReceiptsEthProtocolMessage
+from bxgateway.messages.eth.protocol.receipts_v66_eth_protocol_message import \
+    ReceiptsV66EthProtocolMessage
 from bxgateway.messages.eth.protocol.status_eth_protocol_message import StatusEthProtocolMessage
 from bxgateway.messages.eth.protocol.status_eth_protocol_message_v63 import StatusEthProtocolMessageV63
 from bxgateway.utils.eth.rlpx_cipher import RLPxCipher
@@ -39,16 +45,33 @@ class EthRemoteConnectionProtocol(EthBaseConnectionProtocol):
 
         self.connection.schedule_pings()
 
-    def msg_block_bodies(self, msg: BlockBodiesEthProtocolMessage) -> None:
-        self.node.log_received_remote_blocks(len(msg.get_block_bodies_bytes()))
+    def msg_block_bodies(self, msg: Union[BlockBodiesV66EthProtocolMessage, BlockBodiesEthProtocolMessage]) -> None:
+        if isinstance(msg, BlockBodiesV66EthProtocolMessage):
+            response = msg.get_message()
+        else:
+            response = msg
+
+        self.node.log_received_remote_blocks(len(response.get_block_bodies_bytes()))
         self.msg_proxy_response(msg)
 
-    def msg_block_receipts(self, msg: ReceiptsEthProtocolMessage) -> None:
-        self.node.log_received_remote_blocks(len(msg.get_receipts_bytes()))
+    def msg_block_receipts(self, msg: Union[ReceiptsV66EthProtocolMessage, ReceiptsEthProtocolMessage]) -> None:
+        if isinstance(msg, ReceiptsV66EthProtocolMessage):
+            response = msg.get_message()
+        else:
+            response = msg
+
+        self.node.log_received_remote_blocks(len(response.get_receipts_bytes()))
         self.msg_proxy_response(msg)
 
-    def msg_get_block_bodies(self, msg: GetBlockBodiesEthProtocolMessage) -> None:
-        block_hashes = msg.get_block_hashes()
+    def msg_get_block_bodies(
+        self, msg: Union[GetBlockBodiesV66EthProtocolMessage, GetBlockBodiesEthProtocolMessage]
+    ) -> None:
+        if isinstance(msg, GetBlockBodiesV66EthProtocolMessage):
+            request = msg.get_message()
+        else:
+            request = msg
+
+        block_hashes = request.get_block_hashes()
         logger.debug(
             "Received unexpected get block bodies message from remote "
             "blockchain node for {} blocks: {}. Replying with empty block bodies.",
@@ -57,8 +80,12 @@ class EthRemoteConnectionProtocol(EthBaseConnectionProtocol):
                 [convert.bytes_to_hex(block_hash.binary) for block_hash in block_hashes[:10]]
             )
         )
-        empty_block_bodies_msg = BlockBodiesEthProtocolMessage(None, [])
-        self.connection.enqueue_msg(empty_block_bodies_msg)
+
+        request_id: Optional[int] = None
+        if isinstance(msg, GetBlockBodiesV66EthProtocolMessage):
+            request_id = msg.get_request_id()
+
+        self.send_block_bodies([], request_id)
 
     def msg_block(self, msg: AbstractBlockMessage) -> None:
         raise NotImplemented
