@@ -7,6 +7,7 @@ from bxgateway.messages.gateway.block_propagation_request import BlockPropagatio
 from bxgateway.messages.gateway.block_received_message import BlockReceivedMessage
 from bxgateway.messages.gateway.blockchain_sync_request_message import BlockchainSyncRequestMessage
 from bxgateway.messages.gateway.blockchain_sync_response_message import BlockchainSyncResponseMessage
+from bxgateway.messages.gateway.confirmed_block_message import ConfirmedBlockMessage
 from bxgateway.messages.gateway.confirmed_tx_message import ConfirmedTxMessage
 from bxgateway.messages.gateway.gateway_hello_message import GatewayHelloMessage
 from bxgateway.messages.gateway.gateway_message_type import GatewayMessageType
@@ -23,6 +24,7 @@ class _GatewayMessageFactory(_BloxrouteMessageFactory):
         BloxrouteMessageType.KEY: KeyMessage,
         GatewayMessageType.CONFIRMED_TX: ConfirmedTxMessage,
         GatewayMessageType.REQUEST_TX_STREAM: RequestTxStreamMessage,
+        GatewayMessageType.CONFIRMED_BLOCK: ConfirmedBlockMessage,
 
         # Sync messages are currently unused. See `blockchain_sync_service.py`
         GatewayMessageType.SYNC_REQUEST: BlockchainSyncRequestMessage,
