@@ -1,6 +1,9 @@
+import dataclasses
 import time
+
+from dataclasses import dataclass
 from collections import deque
-from typing import Type, Dict, Deque, Any, TYPE_CHECKING, cast
+from typing import Type, Dict, Deque, Any, TYPE_CHECKING
 
 from bxcommon.utils.object_hash import Sha256Hash
 from bxcommon.utils.stats.statistics_service import StatisticsService, StatsIntervalData
@@ -13,17 +16,18 @@ if TYPE_CHECKING:
     from bxgateway.connections.abstract_gateway_node import AbstractGatewayNode
 
 
+@dataclass
 class GatewayTransactionStatInterval(StatsIntervalData):
-    new_transactions_received_from_blockchain: int
-    duplicate_transactions_received_from_blockchain: int
-    new_full_transactions_received_from_relays: int
-    new_compact_transactions_received_from_relays: int
-    duplicate_full_transactions_received_from_relays: int
-    duplicate_compact_transactions_received_from_relays: int
-    redundant_transaction_content_messages: int
-    short_id_assignments_processed: int
-    transaction_tracker: Dict[Sha256Hash, float]
-    transaction_intervals: Deque[float]
+    new_transactions_received_from_blockchain: int = 0
+    duplicate_transactions_received_from_blockchain: int = 0
+    new_full_transactions_received_from_relays: int = 0
+    new_compact_transactions_received_from_relays: int = 0
+    duplicate_full_transactions_received_from_relays: int = 0
+    duplicate_compact_transactions_received_from_relays: int = 0
+    redundant_transaction_content_messages: int = 0
+    short_id_assignments_processed: int = 0
+    transaction_tracker: Dict[Sha256Hash, float] = dataclasses.field(default_factory=dict)
+    transaction_intervals: Deque[float] = dataclasses.field(default_factory=deque)
 
     total_bdn_transactions_processed: int = 0
     total_bdn_transactions_process_time_ms: float = 0
@@ -37,30 +41,13 @@ class GatewayTransactionStatInterval(StatsIntervalData):
     total_node_transactions_process_time_broadcast_ms: float = 0
     total_node_transactions_process_time_after_broadcast_ms: float = 0
 
-    def __init__(self, *args, **kwargs):
-        super(GatewayTransactionStatInterval, self).__init__(*args, **kwargs)
-        self.new_transactions_received_from_blockchain = 0
-        self.duplicate_transactions_received_from_blockchain = 0
-        self.new_full_transactions_received_from_relays = 0
-        self.new_compact_transactions_received_from_relays = 0
-        self.duplicate_full_transactions_received_from_relays = 0
-        self.duplicate_compact_transactions_received_from_relays = 0
-        self.redundant_transaction_content_messages = 0
-        self.short_id_assignments_processed = 0
-        self.transaction_tracker = {}
-        self.transaction_intervals = deque()
+    tx_validation_failed_gas_price: int = 0
+    tx_validation_failed_structure: int = 0
+    tx_validation_failed_signature: int = 0
 
-        self.total_bdn_transactions_processed = 0
-        self.total_bdn_transactions_process_time_ms = 0
-        self.total_bdn_transactions_process_time_before_ext_ms = 0
-        self.total_bdn_transactions_process_time_ext_ms = 0
-        self.total_bdn_transactions_process_time_after_ext_ms = 0
+    dropped_transactions_from_relay: int = 0
 
-        self.total_node_transactions_processed = 0
-        self.total_node_transactions_process_time_ms = 0
-        self.total_node_transactions_process_time_before_broadcast_ms = 0
-        self.total_node_transactions_process_time_broadcast_ms = 0
-        self.total_node_transactions_process_time_after_broadcast_ms = 0
+    transactions_bytes_skipped: int = 0
 
 
 class _GatewayTransactionStatsService(
@@ -72,7 +59,7 @@ class _GatewayTransactionStatsService(
         self,
         interval: int = gateway_constants.GATEWAY_TRANSACTION_STATS_INTERVAL_S,
         look_back: int = gateway_constants.GATEWAY_TRANSACTION_STATS_LOOKBACK,
-    ):
+    ) -> None:
         super(_GatewayTransactionStatsService, self).__init__(
             "GatewayTransactionStats",
             interval,
@@ -85,66 +72,52 @@ class _GatewayTransactionStatsService(
         return GatewayTransactionStatInterval
 
     def log_transaction_from_blockchain(self, transaction_hash: Sha256Hash) -> None:
-        assert self.interval_data is not None
-        # pyre-fixme[16]: Optional type has no attribute
-        #  `new_transactions_received_from_blockchain`.
         self.interval_data.new_transactions_received_from_blockchain += 1
-        # pyre-fixme[16]: Optional type has no attribute `transaction_tracker`.
         if transaction_hash not in self.interval_data.transaction_tracker:
             self.interval_data.transaction_tracker[transaction_hash] = time.time()
 
     def log_duplicate_transaction_from_blockchain(self) -> None:
-        assert self.interval_data is not None
-        # pyre-fixme[16]: Optional type has no attribute
-        #  `duplicate_transactions_received_from_blockchain`.
         self.interval_data.duplicate_transactions_received_from_blockchain += 1
 
     def log_transaction_from_relay(
         self, transaction_hash: Sha256Hash, has_short_id: bool, is_compact: bool = False
     ) -> None:
-        assert self.interval_data is not None
-        # pyre-fixme[16]: Optional type has no attribute `transaction_tracker`.
         if has_short_id and transaction_hash in self.interval_data.transaction_tracker:
             start_time = self.interval_data.transaction_tracker[transaction_hash]
             if start_time != self.TRANSACTION_SHORT_ID_ASSIGNED_DONE:
-                # pyre-fixme[16]: Optional type has no attribute
-                #  `transaction_intervals`.
                 self.interval_data.transaction_intervals.append(time.time() - start_time)
                 self.interval_data.transaction_tracker[
                     transaction_hash
                 ] = self.TRANSACTION_SHORT_ID_ASSIGNED_DONE
 
         if is_compact:
-            # pyre-fixme[16]: Optional type has no attribute
-            #  `new_compact_transactions_received_from_relays`.
             self.interval_data.new_compact_transactions_received_from_relays += 1
         else:
-            # pyre-fixme[16]: Optional type has no attribute
-            #  `new_full_transactions_received_from_relays`.
             self.interval_data.new_full_transactions_received_from_relays += 1
 
-    def log_short_id_assignment_processed(self):
+    def log_short_id_assignment_processed(self) -> None:
         self.interval_data.short_id_assignments_processed += 1
 
-    def log_duplicate_transaction_from_relay(self, is_compact=False):
-        assert self.interval_data is not None
+    def log_duplicate_transaction_from_relay(self, is_compact=False) -> None:
         if is_compact:
             self.interval_data.duplicate_compact_transactions_received_from_relays += 1
         else:
             self.interval_data.duplicate_full_transactions_received_from_relays += 1
 
+    def log_dropped_transaction_from_relay(self) -> None:
+        interval_data = self.interval_data
+        interval_data.dropped_transactions_from_relay += 1
+
     def log_redundant_transaction_content(self) -> None:
-        assert self.interval_data is not None
-        # pyre-fixme[16]: Optional type has no attribute
-        #  `redundant_transaction_content_messages`.
         self.interval_data.redundant_transaction_content_messages += 1
 
     def log_processed_bdn_transaction(self,
                                       processing_time_ms: float,
                                       processing_time_before_ext_ms: float,
                                       processing_time_ext_ms: float,
-                                      processing_time_after_ext_ms: float):
-        interval_data = cast(GatewayTransactionStatInterval, self.interval_data)
+                                      processing_time_after_ext_ms: float
+                                      ) -> None:
+        interval_data = self.interval_data
         interval_data.total_bdn_transactions_processed += 1
         interval_data.total_bdn_transactions_process_time_ms += processing_time_ms
         interval_data.total_bdn_transactions_process_time_before_ext_ms += processing_time_before_ext_ms
@@ -156,19 +129,31 @@ class _GatewayTransactionStatsService(
                                        duration_before_broadcast_ms: float,
                                        duration_broadcast_ms: float,
                                        duration_set_content_ms: float,
-                                       count: int):
-        interval_data = cast(GatewayTransactionStatInterval, self.interval_data)
+                                       count: int
+                                       ) -> None:
+        interval_data = self.interval_data
         interval_data.total_node_transactions_processed += count
         interval_data.total_node_transactions_process_time_ms += total_duration_ms
         interval_data.total_node_transactions_process_time_before_broadcast_ms += duration_before_broadcast_ms
         interval_data.total_node_transactions_process_time_broadcast_ms += duration_broadcast_ms
         interval_data.total_node_transactions_process_time_after_broadcast_ms += duration_set_content_ms
 
+    def log_tx_validation_failed_signature(self,) -> None:
+        self.interval_data.tx_validation_failed_signature += 1
+
+    def log_tx_validation_failed_structure(self,) -> None:
+        self.interval_data.tx_validation_failed_structure += 1
+
+    def log_tx_validation_failed_gas_price(self,) -> None:
+        self.interval_data.tx_validation_failed_gas_price += 1
+
+    def log_skipped_transaction_bytes(self, skipped_bytes: int) -> None:
+        self.interval_data.transactions_bytes_skipped += skipped_bytes
+
     def get_info(self) -> Dict[str, Any]:
-        assert self.interval_data is not None
-        assert self.node is not None
+        node = self.node
+        assert node is not None
 
-        # pyre-fixme[16]: Optional type has no attribute `transaction_intervals`.
         if len(self.interval_data.transaction_intervals) > 0:
             min_short_id_assign_time = min(self.interval_data.transaction_intervals)
             max_short_id_assign_time = max(self.interval_data.transaction_intervals)
@@ -180,10 +165,10 @@ class _GatewayTransactionStatsService(
             max_short_id_assign_time = 0
             avg_short_id_assign_time = 0
 
-        interval_data = cast(GatewayTransactionStatInterval, self.interval_data)
+        interval_data = self.interval_data
 
         return {
-            "node_id": interval_data.node_id,
+            "node_id": node.opts.node_id,
             "new_transactions_received_from_blockchain": interval_data.new_transactions_received_from_blockchain,
             "duplicate_transactions_received_from_blockchain": interval_data.duplicate_transactions_received_from_blockchain,
             "new_full_transactions_received_from_relays": interval_data.new_full_transactions_received_from_relays,
@@ -191,6 +176,7 @@ class _GatewayTransactionStatsService(
             "duplicate_full_transactions_received_from_relays": interval_data.duplicate_full_transactions_received_from_relays,
             "duplicate_compact_transactions_received_from_relays": interval_data.duplicate_compact_transactions_received_from_relays,
             "redundant_transaction_content_messages": interval_data.redundant_transaction_content_messages,
+            "dropped_transactions_from_relay": interval_data.dropped_transactions_from_relay,
             "short_ids_assignments_processed": interval_data.short_id_assignments_processed,
             "start_time": interval_data.start_time,
             "end_time": interval_data.end_time,
@@ -235,8 +221,11 @@ class _GatewayTransactionStatsService(
                 utils.safe_divide(
                     interval_data.total_node_transactions_process_time_after_broadcast_ms,
                     interval_data.total_node_transactions_processed),
-            # pyre-fixme[16]: Optional type has no attribute `_tx_service`.
-            **self.node._tx_service.get_aggregate_stats(),
+            "rejected_signature": interval_data.tx_validation_failed_signature,
+            "rejected_structure": interval_data.tx_validation_failed_structure,
+            "rejected_gas_price": interval_data.tx_validation_failed_gas_price,
+            "transaction_bytes_skipped": interval_data.transactions_bytes_skipped,
+            **node._tx_service.get_aggregate_stats(),
         }
 
 
